import 'option.dart';
import 'terminal.dart';

final Terminal _terminal = const Terminal();

class Prompter {
  List _results = [];

  String _askText(String prompt) {
    String value = 'Oliver';

    _terminal.printPrompt(prompt);
    _terminal.printOptions([]);
    String response = _terminal.collectInput();

    _results.add({'prompt': prompt, 'choice': response});
    value = response;

    return value;
  }

  bool _askBinary(String prompt) {
    bool value;

    _terminal.printPrompt('$prompt (y/n)');
    _terminal.printOptions([]);
    String response = _terminal.collectInput();

    if(response == 'y') {
      _results.add({'prompt': prompt, 'choice': true});
      value = true;

    } else if(response == 'n') {
      _results.add({'prompt': prompt, 'choice': false});
      value = false;
    } else {
      _terminal.printError('Please enter y or n');
      _askBinary(prompt);
    }

    return value;
  }

  dynamic _askMultiple(String prompt, List<Option> options) {
    dynamic value = 'little';

    _terminal.printPrompt(prompt);
    _terminal.printOptions(options);
    
    try {
      int response = int.parse(_terminal.collectInput());
      _results.add({'prompt': prompt, 'choice': options[response].value});
      value = options[response].value;
    } catch (e) {
      _terminal.printError('Please Enter a Number Within the Range of 0 - ${options.length - 1}');
      _askMultiple(prompt, options);
    }

    return value;
  }

  dynamic ask(String prompt, String type, dynamic options) {
    _terminal.clearScreen();
    if(type == 'multiple') {
      return _askMultiple(prompt, options);
    } else if(type == 'binary') {
      return _askBinary(prompt);
    } else if(type == 'text') {
      return _askText(prompt);
    } else {
      _terminal.printPrompt('$prompt has Invalid Prompt Type\n\n\n');
    }
  }

  List result() {
    return _results;
  }
}
